@@ -32,7 +32,9 @@ signals:
     void removeSignal();
     void popSignal();
     void ClipboardHideSignal();
-    void CLipBoardEditSignal();
+    void CLipBoardEditConfirmButtonSignal();
+    void ClipBoardWidgetEntryEditButtonSignal();
+    void ClipboardPreviewSignal(int width, int height, int x, int y, int taskHeight);
 public slots:
 };
 #endif // SIDEBARCLIPBOARDSIGNAL_H
