@@ -29,20 +29,26 @@
 #include <QTimer>
 #include <QThread>
 #include <QGSettings>
+#include <QProcess>
 
 #define STYLE_FONT_SCHEMA "org.ukui.style"
 #define SYSTEM_FONT_EKY "system-font-size"
 #define SYSTEM_NAME_KEY "system-font"
 
 
-SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, QString strSummary, QDateTime dateTime, QString strBody, bool bTakeInFlag)
+SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, QString strSummary, QDateTime dateTime, QString strBody, QString strUrl, QString strAction, bool bTakeInFlag)
 {
     listenTimeZone();
     m_bMain = true;                 //默认是主窗口
     m_bFold = true;                 //默认折叠状态
+    m_bAppFold = true;              //默认整组消息折叠状态
+    jumpFlag = false;               //默认未点击跳转
+    m_pParent = pParent;
     m_strIconPath = strIconPath;
     m_strSummary = strSummary;
     m_strBody = strBody;
+    m_strUrl = strUrl;
+    m_strAction = strAction;
 
     m_dateTime = dateTime;
     m_uNotifyTime = dateTime.toTime_t();
@@ -92,24 +98,50 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
 
     m_pAnimationBaseMapWidget->setAttribute(Qt::WA_TranslucentBackground);
 
+    QPixmap pixmap;
     pIconToolButton->setFixedSize(24, 24);
     if (strIconPath.contains("file://")) {
         int length = strIconPath.length();
         strIconPath = strIconPath.mid(7, length);
     }
-    QPixmap pixmap = QIcon::fromTheme(strIconPath, QIcon::fromTheme("application-x-desktop")).pixmap(QSize(24, 24));
-    PictureToWhite pictToWhite;
-    pIconToolButton->setPixmap(pictToWhite.drawSymbolicColoredPixmap(pixmap));
-    pIconToolButton->setAttribute(Qt::WA_TranslucentBackground);
+
+    const qreal pixelRatio = qApp->primaryScreen()->devicePixelRatio();
+
+    pixmap = QIcon::fromTheme(strIconPath).pixmap(QSize(24, 24));
+
+
+    if (pixmap.isNull()) {
+        QString iconUrl;
+        const QUrl url(strIconPath);
+        iconUrl = url.isLocalFile() ? url.toLocalFile() : url.url();
+
+        if (strIconPath.contains("file://")) {
+            int length = strIconPath.length();
+            strIconPath = strIconPath.mid(7, length);
+        }
+        const QIcon &icon = QIcon::fromTheme(strIconPath, QIcon::fromTheme("application-x-desktop"));
+        pixmap = icon.pixmap(width() * pixelRatio, height() * pixelRatio);
+    }
+
+
+    if (!pixmap.isNull()) {
+        pixmap = pixmap.scaled(pIconToolButton->width() * pixelRatio, pIconToolButton->height() * pixelRatio,
+                               Qt::KeepAspectRatioByExpanding,
+                               Qt::SmoothTransformation);
+
+        pixmap.setDevicePixelRatio(pixelRatio);
+
+    }
+    pIconToolButton->setPixmap(pixmap);
 
     //获取系统字体大小
     QFont ft;
-    ft.setPointSize(14);
+    int fontSize;
     if(QGSettings::isSchemaInstalled(STYLE_FONT_SCHEMA))
     {
         const QByteArray styleID(STYLE_FONT_SCHEMA);
         stylesettings = new QGSettings(styleID);
-        int fontSize = stylesettings->get("system-font-size").toInt();
+        fontSize = stylesettings->get("system-font-size").toInt();
         ft.setPointSize(fontSize);
     }
     connect(stylesettings, SIGNAL(changed(const QString &)), this, SLOT(slotChangeFonts(const QString &)));
@@ -121,14 +153,14 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     pAppNameLabel->setFont(ft);
     QFontMetrics fontMetrics1(pAppNameLabel->font());
     QString formatAppName = fontMetrics1.elidedText(strAppName, Qt::ElideRight, pAppNameLabel->width());
-    pAppNameLabel->setText(formatAppName);
+    pAppNameLabel->setText(formatAppName);//第一行
 
     //设置通知消息中的弹簧，水平任意伸缩使应用名和时间分开
     QSpacerItem* pHExpandSpacer = new QSpacerItem(500, 10, QSizePolicy::Expanding, QSizePolicy::Fixed);
 
     //放置时间和收纳删除按钮的窗口
     m_pTimeLabelWidget = new QWidget;
-    m_pTimeLabelWidget->setFixedSize(146, 20);
+    m_pTimeLabelWidget->setFixedSize(146, 22);
     QHBoxLayout* pTimeLableHLayout = new QHBoxLayout();
 
 
@@ -139,7 +171,7 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     //设置通知消息中的通知时间
     m_pTimeLabel = new QLabel();
     m_pTimeLabel->setObjectName("pushtime");
-    m_pTimeLabel->setText(tr("now"));
+    m_pTimeLabel->setText(tr("now"));//提示时间
     m_pTimeLabel->setAttribute(Qt::WA_TranslucentBackground);
 
     //收纳删除按钮图标的大小
@@ -217,10 +249,10 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     //延时1秒设置字体
     QTimer::singleShot(1, m_pSummaryLabel, [=]() {
             QFont summaryFont = m_pSummaryLabel->font();
-            summaryFont.setPointSizeF(12);
-            summaryFont.setFamily("Noto Sans CJK SC");
+            summaryFont.setPointSizeF(fontSize + 2);
+//            summaryFont.setFamily("Noto Sans CJK SC");
             summaryFont.setBold(true);
-            m_pSummaryLabel->setFont(summaryFont);
+            m_pSummaryLabel->setFont(summaryFont);//第二行正文
         });
 
     QString formatSummary;
@@ -279,6 +311,7 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     m_pAppVLaout->addWidget(m_pSingleWidget);
     this->setLayout(m_pAppVLaout);
     m_pSetDeleDelayTimer = new QTimer(this);
+    m_pSetJumpDelayTimer = new QTimer(this);
     return;
 }
 
@@ -328,8 +361,6 @@ void SingleMsg::listenTimeZoneSlots()
 
 void SingleMsg::slotChangeFonts(const QString &key)
 {
-    if(key != "systemFontSize")
-        return;
     QFont ft;
     int fontSize = 12;
     ft.setPointSize(20);
@@ -351,7 +382,7 @@ void SingleMsg::slotChangeFonts(const QString &key)
     QTimer::singleShot(1, m_pSummaryLabel, [=]() {
             QFont summaryFont = m_pSummaryLabel->font();
             summaryFont.setPointSizeF(fontSize+3);
-            summaryFont.setFamily("Noto Sans CJK SC");
+//            summaryFont.setFamily("Noto Sans CJK SC");
             summaryFont.setBold(true);
             m_pSummaryLabel->setFont(summaryFont);
         });
@@ -379,6 +410,36 @@ void SingleMsg::initGsettingValue()
         m_pStyleGsetting = new QGSettings(id);
 }
 
+void SingleMsg::jumpAction()
+{
+    //关闭该条通知
+    onDele();
+    //跳转动作
+    m_pSetJumpDelayTimer->setSingleShot(true);      //延迟30毫秒，等待删除完成后跳转
+    connect(m_pSetJumpDelayTimer, &QTimer::timeout, this, [=](){
+        if(!m_strUrl.isEmpty()){
+            QString cmd = QString("xdg-open ") + m_strUrl;
+            qInfo()<<"Jump Url:"<<cmd;
+            system(cmd.toStdString().c_str());
+            emit Sig_onDeleSingleMsg(this);
+        }
+        else if(!m_strAction.isEmpty()){
+            qInfo()<<"Jump Action:"<<m_strAction;
+            QProcess *process = new QProcess();
+            process->start(m_strAction);
+            emit Sig_onDeleSingleMsg(this);
+        }
+        else{
+            emit Sig_onDeleSingleMsg(this);
+        }
+    });
+    connect(this,&SingleMsg::Sig_jumpAction,this,[=](){
+        m_pSetJumpDelayTimer->start(30);
+    });
+
+    return;
+}
+
 void SingleMsg::paintEvent(QPaintEvent *e)
 {
 
@@ -491,15 +552,22 @@ void SingleMsg::updatePushTime()
             strPushDate =  m_dateTime.toString("ddd AP h:mm");              //12小时制
         }
         m_pTimeLabel->setText(strPushDate);
-    }
-    else
-    {
-        strPushDate = m_dateTime.toString("yyyy/MM/dd");                    //一周以外
+    } else {
+        //一周以外
+        if (QGSettings::isSchemaInstalled( "org.ukui.control-center.panel.plugins")) {
+            QGSettings  *m_pFontGsetting = new QGSettings( "org.ukui.control-center.panel.plugins");
+            if (m_pFontGsetting != nullptr) {
+                if (m_pFontGsetting->get("date").toString() == "cn"){
+                    strPushDate = m_dateTime.toString("yyyy/MM/dd");
+                } else {
+                    strPushDate = m_dateTime.toString("yyyy-MM-dd");
+                }
+            }
+        }
         m_pTimeLabel->setText(strPushDate);
     }
 
     return;
-
 }
 
 void SingleMsg::setBodyLabelWordWrap(bool bFlag)
@@ -534,7 +602,7 @@ void SingleMsg::setBodyLabelWordWrap(bool bFlag)
             strDisplay += QString(m_strBody.at(i));
             uint fontSize = fontMetrics.width(strDisplay);
             if(fontSize > (j*(labelWidth-8))){
-                strDisplay+=" ";
+//                strDisplay+=" ";
                 j++;
             }
         }
@@ -565,7 +633,7 @@ void SingleMsg::setLeftItem(int nShowLeftCount)
     m_pShowLeftItemLabel->setAttribute(Qt::WA_TranslucentBackground);
 
     //当剩余条数大于0, 且是折叠状态则显示剩余标签
-    if((true == m_bFold) && (m_nShowLeftCount > 0))
+    if((true == m_bAppFold) && (m_nShowLeftCount > 0))
     {
         m_pAppVLaout->setContentsMargins(0,0,0,0); //假如折叠，剩余条目显示将可见，则SingleMsg的内容均无空隙
         m_pShowLeftItemLabel->setVisible(true);
@@ -595,13 +663,11 @@ void SingleMsg::enterEvent(QEvent *event)
     m_pTimeLabelWidget->hide();
     m_pIconHLayout->setContentsMargins(10, 11, 0, 0);
 
-    if((true == m_bMain) && (true == m_bFold) && (m_nShowLeftCount > 0))
+    if((true == m_bMain) && (true == m_bAppFold) && (m_nShowLeftCount > 0))
     {
         emit Sig_onMainEnter();
     }
     this->update();
-    QTimer::singleShot(50,[this]{this->update();});
-
     return;
 }
 
@@ -613,7 +679,7 @@ void SingleMsg::leaveEvent(QEvent *event)
     m_pTimeLabelWidget->show();
     m_pStorageDeleteButtonWidget->hide();
     m_pIconHLayout->setContentsMargins(10, 11, 0, 0);
-    if((true == m_bMain) && (true == m_bFold) && (m_nShowLeftCount > 0))
+    if((true == m_bMain) && (true == m_bAppFold) && (m_nShowLeftCount > 0))
     {
         emit Sig_onMainLeave();
     }
@@ -621,39 +687,40 @@ void SingleMsg::leaveEvent(QEvent *event)
     return;
 }
 
-//鼠标点击事件
+//鼠标点击事件:1、折叠状态下展开消息 2、展开状态下执行跳转动作
 void SingleMsg::mousePressEvent(QMouseEvent *event)
 {
     status =PRESS;
     if (event->buttons() == Qt::LeftButton)
     {
-        if(true == m_bFold)
-        {
-            m_bFold = false;                                //置为false,表示展开
-            setBodyLabelWordWrap(true);
-        }
-        else
-        {
-            m_bFold = true;                                 //置为true,表示折叠
-            setBodyLabelWordWrap(false);
-        }
+        if(m_pParent->getFoldFlag()){   //折叠状态
+            if(true == m_bMain){
+                if(m_pParent->getSingleMsgCount()<=1){
+                    if(m_bFold){
+                        //折叠状态下展开单条消息
+                        setBodyLabelWordWrap(true);
+                        setFoldFlag(false);
 
-        //当消息为主窗口时,发送折叠信息给App
-        if(true == m_bMain)
-        {
-            //当剩余条数大于0, 且是折叠状态则显示剩余标签
-            if((true == m_bFold) && (m_nShowLeftCount > 0))
-            {
-                emit Sig_onMainEnter();
+                    }else{
+                        //已经展开的消息执行跳转
+                        jumpFlag = true;
+                        jumpAction();
+                    }
+                }
+                else{
+                    //展开整个app消息
+                    if(true == m_bAppFold){
+                        m_bAppFold = false;                                //置为false,表示展开
+                        m_pShowLeftItemLabel->setVisible(false);        //展开时，剩余条目设置为不可见
+                        emit Sig_setAppFoldFlag(m_bAppFold);               //展开设置，即开始展开动画
+                    }
+                }
             }
-            else
-            {
-                emit Sig_onMainLeave();                     //点击后也让app的分层底图恢复原色
-                m_pAppVLaout->setContentsMargins(0,0,0,6);  //假如展开，剩余条目显示不可见，则SingleMsg的内容空白恢复正常，即底部多出6个px的空隙
-                m_pShowLeftItemLabel->setVisible(false);
-            }
-
-            emit Sig_setAppFoldFlag(m_bFold);
+        }
+        else{
+            //执行跳转动作
+            jumpFlag = true;
+            jumpAction();
         }
         this->update();
     }
@@ -666,7 +733,8 @@ void SingleMsg::mainMsgSetFold()
     if(true == m_bMain)
     {
         //置为true,表示折叠
-        m_bFold = true;
+        m_bAppFold = true;
+        setFoldFlag(true);
         setBodyLabelWordWrap(false);
 
         //当剩余条数大于0, 且是折叠状态则显示剩余标签
@@ -700,7 +768,7 @@ void SingleMsg::startAnimationUnfold()
 
     //设置show动画
     QPropertyAnimation* pAnimation = new QPropertyAnimation(m_pSingleWidget, "geometry");
-    pAnimation->setDuration(300);
+    pAnimation->setDuration(50);
     connect(pAnimation, &QPropertyAnimation::valueChanged, this, &SingleMsg::updateUnfoldMove);
     connect(pAnimation, SIGNAL(finished()), this, SLOT(onUnfoldFinish()));
 
@@ -722,7 +790,7 @@ void SingleMsg::startAnimationFold()
 
     //设置show动画
     QPropertyAnimation* pAnimation = new QPropertyAnimation(m_pSingleWidget, "geometry");
-    pAnimation->setDuration(300);
+    pAnimation->setDuration(50);
     connect(pAnimation, &QPropertyAnimation::valueChanged, this, &SingleMsg::updateFoldMove);
     connect(pAnimation, SIGNAL(finished()), this, SLOT(onFoldFinish()));
 
@@ -738,7 +806,6 @@ void SingleMsg::startAnimationDeleLeftMove()
     int nHeight = this->height();
     QDateTime currentDateTime(QDateTime::currentDateTime());
     QString strCurrentTime = currentDateTime.toString("hh:mm:ss.zzz");
-    qDebug()<<strCurrentTime <<"SingleMsg::setAnimationDeleStatus"<<this <<nWidth <<nHeight;
 
     nHeight = nHeight - 6;                  //减去底部6px的空白区域，得出动画框体偏移高度
 
@@ -779,7 +846,7 @@ void SingleMsg::startAnimationDeleUpperMove()
 //通知中心或者收纳盒中的删除
 void SingleMsg::onDele()
 {
-    if((true == m_bMain) && (true == m_bFold) && (m_nShowLeftCount > 0))
+    if((true == m_bMain) && (true == m_bAppFold) && (m_nShowLeftCount > 0))
     {
         m_pAppVLaout->setContentsMargins(0,0,0,6);
         emit Sig_notifyAppHideBaseMap();                    //通知隐藏应用的底图部件，但保留显示底部6px的空白
@@ -796,7 +863,7 @@ void SingleMsg::onDele()
 //通知中心消息收纳至收纳盒
 void SingleMsg::onTakeIn()
 {
-    if((true == m_bMain) && (true == m_bFold) && (m_nShowLeftCount > 0))
+    if((true == m_bMain) && (true == m_bAppFold) && (m_nShowLeftCount > 0))
     {
         emit Sig_onTakeinWholeApp();
     }
@@ -811,7 +878,7 @@ void SingleMsg::onTakeIn()
 //收纳盒消息恢复至通知中心
 void SingleMsg::onRecover()
 {
-    if((true == m_bMain) && (true == m_bFold) && (m_nShowLeftCount > 0))
+    if((true == m_bMain) && (true == m_bAppFold) && (m_nShowLeftCount > 0))
     {
         emit Sig_onRecoverWholeApp();
     }
@@ -880,7 +947,7 @@ void SingleMsg::onUnfoldFinish()
 {
     m_pAppVLaout->removeWidget(m_pAnimationBaseMapWidget);
     m_pAnimationBaseMapWidget->setVisible(false);
-    m_pAppVLaout->addWidget(m_pSingleWidget);   
+    m_pAppVLaout->addWidget(m_pSingleWidget);
 }
 
 //处理折叠完成时的函数
@@ -936,13 +1003,19 @@ void SingleMsg::updateDeleUpperMove(const QVariant &value)
 //处理删除上移完成时的函数
 void SingleMsg::onDeleUpperMoveFinish()
 {
-    if((true == m_bMain) && (true == m_bFold) && (m_nShowLeftCount > 0))
+    if((true == m_bMain) && (true == m_bAppFold) && (m_nShowLeftCount > 0))  //点击的是折叠状态下的主消息的删除按钮
     {
         emit Sig_onDeleteAppMsg();
     }
-    else
-    {
-        emit Sig_onDeleSingleMsg(this);
+    else if((true == m_bMain) && (m_nShowLeftCount == 0) && jumpFlag){     //仅有一条消息时点击消息体
+        emit Sig_jumpAction();
+    }
+    else{
+        if(jumpFlag){
+            emit Sig_jumpAction();
+        }else{
+            emit Sig_onDeleSingleMsg(this);
+        }
     }
 
 }
