@@ -16,9 +16,27 @@
 *
 */
 #include "sidebarpluginswidgets.h"
+#include <qt5xdg/XdgDesktopFile>
+#include <qt5xdg/XdgIcon>
+
 extern double tranSparency;
 
 static sidebarPluginsWidgets *global_Plugin_Widgets_instance = nullptr;
+
+m_ToolButton::m_ToolButton()
+{
+
+}
+
+void m_ToolButton::enterEvent(QEvent *event)
+{
+    char*  charname ;
+    QByteArray ba = pluginname.toLocal8Bit();
+    charname =ba.data();
+    this->setToolTip((tr(charname)));
+    return;
+}
+
 sidebarPluginsWidgets::sidebarPluginsWidgets(QWidget *parent) : QWidget(parent)
 {
     Q_UNUSED(parent);
@@ -26,14 +44,6 @@ sidebarPluginsWidgets::sidebarPluginsWidgets(QWidget *parent) : QWidget(parent)
     this->setContentsMargins(0,0,0,0);
     this->setFixedSize(400,300);
     this->setStyleSheet("QWidget{background:rgba(255, 255, 0, 0);}");
-    flagnumClipboardState = 0;
-
-
-    m_pBoolStates = true;
-    resizeFlagOne = true;
-
-    ClipBoardBool = false;
-    SmallPluginsBool = false;
 
     m_pWidgetOutVLayout = new QVBoxLayout();
     m_pWidgetOutVLayout->setContentsMargins(0,0,0,0);
@@ -96,14 +106,15 @@ void sidebarPluginsWidgets::initUpGroupBoxButton()
     m_pClipboardButton = new SmallPluginsButton();
     m_pClipboardButton->setText(tr("Clipboard"));
     m_pClipboardButton->setObjectName("ClipboardButton");
-    m_pClipboardButton->setFixedSize(90,34);
+    m_pClipboardButton->setMinimumWidth(110);
+    m_pClipboardButton->setFixedHeight(34);
     connect(m_pClipboardButton, &SmallPluginsButton::clicked, this, &sidebarPluginsWidgets::m_ClipboardButtonSlots);
 
     //小插件按钮
     m_pSidebarPluginButton = new SmallPluginsButton();
     m_pSidebarPluginButton->setText(tr("Plugins"));
     m_pSidebarPluginButton->setObjectName("SidebarPluginButton");
-    m_pSidebarPluginButton->setFixedSize(90,34);
+    m_pSidebarPluginButton->setFixedSize(110,34);
     connect(m_pSidebarPluginButton, &SmallPluginsButton::clicked, this, &sidebarPluginsWidgets::m_SidebarPluginButtonSlots);
 
     setClipboardButtonBackgroundIsBlue();
@@ -120,7 +131,7 @@ void sidebarPluginsWidgets::initUpGroupBoxButton()
 
     //蓝色背景块按钮
     m_pBlueBackgroundButton = new QPushButton();
-    m_pBlueBackgroundButton->setFixedSize(90, 34);
+    m_pBlueBackgroundButton->setFixedSize(110, 34);
     m_pBlueBackgroundButton->setObjectName("BlueBackgroundButton");
     m_pBlueBackgroundButton->setChecked(false);
 
@@ -130,14 +141,11 @@ void sidebarPluginsWidgets::initUpGroupBoxButton()
     m_pGrouBoxUpButtonHLayout->addWidget(m_pClipboardButton);
     m_pGrouBoxUpButtonHLayout->addItem(new QSpacerItem(10, 20));
     m_pGrouBoxUpButtonHLayout->addWidget(m_pSidebarPluginButton);
-    m_pGrouBoxUpButtonHLayout->addItem(new QSpacerItem(10, 20));
-//    m_pGrouBoxUpButtonHLayout->addWidget(m_pFoldButton);
-//    m_pGrouBoxUpButtonHLayout->addWidget(m_pSpreadButton);
+    m_pGrouBoxUpButtonHLayout->addItem(new QSpacerItem(0, 20));
     m_pGrouBoxUpButtonHLayout->addWidget(m_pBlueBackgroundButton);
-    m_pGrouBoxUpButtonHLayout->addItem(new QSpacerItem(202, 20));
+    m_pGrouBoxUpButtonHLayout->addItem(new QSpacerItem(200, 20, QSizePolicy::Expanding));
     m_pButtonWidget->setLayout(m_pGrouBoxUpButtonHLayout);
     m_pGrouBoxUpButtonHLayout->setSpacing(0);
-//    m_pButtonWidget->setStyleSheet("QWidget{ border: 1px solid rgba(255,255,0,1);}");
     return;
 }
 
@@ -288,22 +296,22 @@ void sidebarPluginsWidgets::m_AnimationSmallWidgetEndSlots()
 /* 设置侧边栏的按钮背景色为蓝色 */
 void sidebarPluginsWidgets::setClipboardButtonBackgroundIsBlue()
 {
-    m_pClipboardButton->setStyleSheet("QPushButton#ClipboardButton{background:rgba(61,107,229,1);}");
+    m_pClipboardButton->setStyleSheet("QPushButton#ClipboardButton{background:rgba(61,107,229,1);padding-left:0px;padding-right:0px;}");
 }
 
 void sidebarPluginsWidgets::setSmallPluginsButtonBackgroudIsBlue()
 {
-    m_pSidebarPluginButton->setStyleSheet("QPushButton#SidebarPluginButton{background:rgba(61,107,229,1);}");
+    m_pSidebarPluginButton->setStyleSheet("QPushButton#SidebarPluginButton{background:rgba(61,107,229,1);padding-left:0px;padding-right:0px;}");
 }
 
 void sidebarPluginsWidgets::setClipboardButtonBackgroundIsBlank()
 {
-    m_pClipboardButton->setStyleSheet("QPushButton#ClipboardButton{background:rgba(61,107,229,0);}");
+    m_pClipboardButton->setStyleSheet("QPushButton#ClipboardButton{background:rgba(61,107,229,0);padding-left:0px;padding-right:0px;}");
 }
 
 void sidebarPluginsWidgets::setSmallPluginsButtonBackgroudIsBlank()
 {
-    m_pSidebarPluginButton->setStyleSheet("QPushButton#SidebarPluginButton{background:rgba(61,107,229,0);}");
+    m_pSidebarPluginButton->setStyleSheet("QPushButton#SidebarPluginButton{background:rgba(61,107,229,0);padding-left:0px;padding-right:0px;}");
 }
 
 /* 设置剪贴板的高度 */
@@ -369,9 +377,8 @@ void sidebarPluginsWidgets::addDesktopFileName()
 {
     m_desktopfpList.append("ukui-clock.desktop");
     m_desktopfpList.append("ukui-notebook.desktop");
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0))
+//    m_desktopfpList.append("kylin-service-support.desktop");
     m_desktopfpList.append("ukui-feedback.desktop");
-#endif
     return;
 }
 
@@ -383,56 +390,161 @@ void sidebarPluginsWidgets::parsingDesktopFile()
     QSpacerItem *item1 = new QSpacerItem(10, 20);
     for (int i = 0; i < tmp; i++) {
         QString desktopfp = "/usr/share/applications/" + m_desktopfpList.at(i);
-        QString icon = getAppIcon(desktopfp);
-        QString name = getAppName(desktopfp);
-        QString Exec = getAppExec(desktopfp);
-        QToolButton *p_button = StructToolButtol(icon, name);
-        connect(p_button, &QToolButton::clicked, this, [=](){
-            QProcess p(0);
-            p.startDetached(Exec);
-            p.waitForStarted();
-            return;
-        });
-        if (p_button == nullptr) {
-            continue;
-            i--;
+//        QString icon = getAppIcon(desktopfp);
+//        QString name = getAppName(desktopfp);
+//        QString Exec = getAppExec(desktopfp);
+
+        //使用xdg解析desktop文件
+        if(QFile::exists(desktopfp)){
+            XdgDesktopFile xdg;
+            xdg.load(desktopfp);
+            QString name = xdg.localizedValue("Name").toString();
+            QString icon = xdg.localizedValue("Icon").toString();
+            QString Exec = xdg.localizedValue("Exec").toString();
+
+            m_ToolButton *p_button = StructToolButtol(icon, name);
+            connect(p_button, &QToolButton::clicked, this, [=]() {
+                QProcess p(0);
+                p.startDetached(Exec);
+                p.waitForStarted();
+                return;
+            });
+            if (p_button == nullptr) {
+                continue;
+                i--;
+            }
+            m_pGroupBoxUnSmallPluginsGLayout->addItem(item1, m_add_x, m_add_y - 1);
+            m_pGroupBoxUnSmallPluginsGLayout->addWidget(p_button, m_add_x, m_add_y);
+            m_add_y += 2;
+            if (m_add_y > 8) {
+                m_add_x++;
+                m_add_y = 1;
+            }
+            qDebug() << "add_y" << m_add_y << "add_x" << m_add_x;
         }
-        m_pGroupBoxUnSmallPluginsGLayout->addItem(item1, m_add_x, m_add_y - 1);
-        m_pGroupBoxUnSmallPluginsGLayout->addWidget(p_button, m_add_x, m_add_y);
-        m_add_y += 2;
-        if (m_add_y > 8) {
-            m_add_x++;
-            m_add_y = 1;
-        }
-        qDebug() << "add_y" << m_add_y << "add_x" << m_add_x;
+
     }
     return;
 }
 
 /* 构建小插件图标 */
-QToolButton* sidebarPluginsWidgets::StructToolButtol(QString icon, QString name)
+m_ToolButton* sidebarPluginsWidgets::StructToolButtol(QString icon, QString name)
 {
-    QToolButton *p_ToolButton = new QToolButton();
+    m_ToolButton *p_ToolButton = new m_ToolButton();
     p_ToolButton->setFixedSize(90,90);
     QPixmap pixmap = QIcon::fromTheme(icon).pixmap(QSize(45, 45));
     QLabel *IconLabel = new QLabel();
     IconLabel->setFixedSize(45, 45);
     IconLabel->setPixmap(pixmap);
+
+    const QByteArray id(THEME_QT_SCHEMA);
+    if (QGSettings::isSchemaInstalled(id)) {
+        QGSettings *styleSettings = new QGSettings(id);
+        connect(styleSettings,&QGSettings::changed,this,[=](const QString &key){
+        QPixmap pixmap = QIcon::fromTheme(icon).pixmap(QSize(45, 45));
+        IconLabel->setPixmap(pixmap);
+    });
+    }
+
     QLabel *textLabel = new QLabel();
-    textLabel->setText(name);
+    textLabel->setText(SetFormatBody(name, textLabel));
+    m_LabelTextMap.insert(textLabel, name);
+    connect(this, &sidebarPluginsWidgets::FontModifyComplete, this, [=](){
+        QString name = m_LabelTextMap.value(textLabel);
+        QString formatName = SetFormatBody(name, textLabel);
+        textLabel->setText(formatName);
+        qDebug() << "收到所有字体修改完成的信号";
+    });
+
     QVBoxLayout *ToolButtonLaout = new QVBoxLayout();
     ToolButtonLaout->setContentsMargins(0, 0, 0, 0);
     ToolButtonLaout->addItem(new QSpacerItem(10, 12, QSizePolicy::Expanding));
     ToolButtonLaout->addWidget(IconLabel, 0, Qt::AlignCenter);
     ToolButtonLaout->addItem(new QSpacerItem(10, 9, QSizePolicy::Expanding));
-    ToolButtonLaout->addWidget(textLabel, 0, Qt::AlignCenter);
+    ToolButtonLaout->addWidget(textLabel, 1, Qt::AlignCenter);
     ToolButtonLaout->addSpacerItem(new QSpacerItem(10, 7));
     p_ToolButton->setLayout(ToolButtonLaout);
     p_ToolButton->setStyle(new CustomStyle("ukui-default"));
     qDebug() << "插件接口名称" << name;
+    p_ToolButton->pluginname=name;
     return p_ToolButton;
 }
 
+/* 设置...字样 */
+QString sidebarPluginsWidgets::SetFormatBody(QString text, QLabel *label)
+{
+    QFontMetrics fontMetrics(label->font());
+    int LableWidth = label->width();
+    int fontSize = fontMetrics.width(text);
+    qDebug() << "内容name---->" << text << "字体宽度---->fontsize" << fontSize;
+    QString formatBody = text;
+    if(fontSize > (80)) {
+        QStringList list = formatBody.split("\n");
+        if (list.size() >= 2) {
+            //当有几行时，只需要截取第一行就行，在第一行后面加...
+            // 判断第一行是否是空行
+            formatBody = judgeBlankLine(list);
+            formatBody = formatBody + "aa";
+            int oneFontSize = fontMetrics.width(formatBody);
+            if (oneFontSize > (80)) {
+                formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, 80);
+                return formatBody;
+            } else {
+                if (!substringSposition(formatBody, list)) {
+                    int oneFontSize = fontMetrics.width(formatBody);
+                    formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, oneFontSize - 1);
+                    return formatBody;
+                }
+            }
+        } else {
+            //说明只存在一行，在最后面加...就行
+            formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight,80);
+            qDebug() << "当前format-----》" << formatBody << "字体宽度---->" << fontSize;
+            return formatBody;
+        }
+    } else {
+        QStringList list = formatBody.split("\n");
+        if (list.size() >= 2) {
+            //取得当前的有字符串的子串
+            formatBody = judgeBlankLine(list);
+            formatBody = formatBody + "aa";
+            if (!substringSposition(formatBody, list)) {
+                int oneFontSize = fontMetrics.width(formatBody);
+                formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, oneFontSize - 1);
+            }
+        }
+    }
+    return formatBody;
+}
+
+/* 去除掉空行，显示有字体的行 */
+QString sidebarPluginsWidgets::judgeBlankLine(QStringList list)
+{
+    int tmp = list.count();
+    for (int i = 0; i < tmp; i++) {
+        QString dest = list.at(i);
+        dest = dest.trimmed();
+        if (dest.size() != 0) {
+           return list.at(i);
+        }
+    }
+    return list.at(0);
+}
+
+/* 判断当前子串位置，后面是否还有子串 */
+bool sidebarPluginsWidgets::substringSposition(QString formatBody, QStringList list)
+{
+    int tmp = list.count();
+    for (int i = 0; i < tmp; i++) {
+        QString dest = list.at(i);
+        if (dest == formatBody && i == tmp - 1) {
+            qDebug() << "后面没有字串，返回true";
+            return true;
+        }
+    }
+    return false;
+}
+
 void sidebarPluginsWidgets::setButtonFont()
 {
     QPalette paletteButton = QApplication::palette();
