@@ -44,6 +44,24 @@
 #include "customstyleCleanPushbutton.h"
 #include "customstyle.h"
 
+#define THEME_QT_SCHEMA "org.ukui.style"
+#define MODE_QT_KEY "style-name"
+#define FONT_SIZE "system-font-size"
+
+
+
+class m_ToolButton : public QToolButton
+{
+
+public:
+    explicit m_ToolButton();
+    QString pluginname;
+    void enterEvent(QEvent *event);
+signals:
+
+};
+
+
 class sidebarPluginsWidgets : public QWidget
 {
     Q_OBJECT
@@ -58,7 +76,6 @@ public:
     void initLableBackgroundAnimation();                          //初始化动画
     void initCliboardAnimation();                                 //初始化剪贴板动画类
     void initSmallPluginsAnimation();                             //初始化小插件动画类
-//    void initTransparencyGsetting();                              //初始化gsetting值
     void setClipboardButtonBackgroundIsBlue();                    //设置侧边栏按钮背景色为蓝色
     void setSmallPluginsButtonBackgroudIsBlue();                  //设置小插件按钮背景色为蓝色
     void setClipboardButtonBackgroundIsBlank();                   //设置侧边栏按钮背景色为空白
@@ -71,10 +88,15 @@ public:
     QString getAppName(QString desktopfp);                        //获取插件名称
     QString getAppExec(QString desktopfp);                        //获取应用可执行文件路径
     void    addDesktopFileName();                                 //将小插件desktop文件名称放入到desktopfpList中
+
     void    parsingDesktopFile();                                 //解析desktop文件
-    QToolButton* StructToolButtol(QString icon, QString name);    //构建QToolButton
+    m_ToolButton* StructToolButtol(QString icon, QString name);    //构建QToolButton
     QStringList m_desktopfpList;                                  //保存当前小插件desktop文件名称
 
+    QString SetFormatBody(QString text, QLabel *label);           //设置...
+    QString judgeBlankLine(QStringList list);
+    bool    substringSposition(QString formatBody, QStringList list);
+
     QVBoxLayout *m_pWidgetOutVLayout;                             //最外层布局
     QHBoxLayout *m_pGrouBoxUpButtonHLayout;                       //GroupBox中Button中的布局
     QGridLayout *m_pGroupBoxUnSmallPluginsGLayout;                //闹钟，便签本布局
@@ -98,23 +120,20 @@ public:
     QPropertyAnimation *m_pAnimationClipbarod;
     QPropertyAnimation *m_pAnimationSmallWidget;
 
-    QGSettings      *m_pTransparency = nullptr;                  //透明度gsetting值
+    QGSettings      *m_pTransparency = nullptr;                   // 透明度gsetting值
 
     //状态机
-    QStateMachine *m_pMachine;                                    // 状态机
-    QState *m_pClipBoardState;                                    // 剪贴板状态
-    QState *m_pSmallPluginsState;                                 // 小插件状态
-    bool    m_pBoolStates;                                        // 第一次初始化状态机bool值
-    bool    resizeFlagOne;                                        // 第一次初始化状态机bool值
-    bool    ClipBoardBool;                                        // 剪贴板修改屏幕分辨率bool值
-    bool    SmallPluginsBool;                                     // 插件按钮修改屏幕分辨率bool值
-    int     m_statusFlag;                                         // 状态机位置
-    int     flagnumClipboardState;
+    bool    ClipBoardBool = false;                                // 剪贴板修改屏幕分辨率bool值
+    bool    SmallPluginsBool = false;                             // 插件按钮修改屏幕分辨率bool值
+
     int     m_add_x = 0;
     int     m_add_y = 1;
     int     m_cliboardHight;                                      // 剪贴板和小插件的高度
+    QMap<QLabel*, QString> m_LabelTextMap;                        // 保存label原始字符串的Map表
+
 
 signals:
+    void FontModifyComplete();
 
 private slots:
     void m_pClipBoardStateSlots();
