@@ -4,61 +4,66 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="65"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="94"/>
         <source>Notification center</source>
         <translation>通知中心</translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="112"/>
-        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="681"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="137"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="609"/>
         <source>Important notice</source>
         <translation>重要的通知</translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="120"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="145"/>
         <source>Clean up</source>
         <translation>清空</translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="151"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="153"/>
         <source>Set up</source>
         <translation>设置</translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="217"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="202"/>
         <source>No new notifications</source>
         <translation>没有新通知</translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="240"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="228"/>
         <source>No unimportant notice</source>
         <translation>没有不重要的通知</translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="653"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/notificationPlugin.cpp" line="586"/>
         <source>Unimportant notice</source>
         <translation>不重要的通知</translation>
     </message>
+    <message>
+        <location filename="../../src/plugins/ukui-sidebar-notification/appmsg.cpp" line="53"/>
+        <source> fold</source>
+        <translation>折叠</translation>
+    </message>
 </context>
 <context>
     <name>SingleMsg</name>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="116"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="174"/>
         <source>now</source>
         <translation>现在</translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="284"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="533"/>
         <source>Yesterday </source>
         <translation>昨天 </translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="363"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="624"/>
         <source>In addition </source>
         <translation>还有 </translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="363"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/singlemsg.cpp" line="624"/>
         <source> notification</source>
         <translation type="unfinished"> 则通知</translation>
     </message>
@@ -70,12 +75,12 @@
 <context>
     <name>TakeInBoxToolButton</name>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/takeinboxtoolbutton.cpp" line="36"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/takeinboxtoolbutton.cpp" line="38"/>
         <source>Enter unimportant news</source>
         <translation type="unfinished">进入不重要通知</translation>
     </message>
     <message>
-        <location filename="../../src/plugins/ukui-sidebar-notification/takeinboxtoolbutton.cpp" line="41"/>
+        <location filename="../../src/plugins/ukui-sidebar-notification/takeinboxtoolbutton.cpp" line="42"/>
         <source>Quit unimportant news</source>
         <translation type="unfinished">退出不重要通知</translation>
     </message>
